Package: plmmr
Title: Penalized Linear Mixed Models for Correlated Data
Version: 4.3.0
Authors@R: c(
    person("Tabitha K.", "Peter", , "tabitha.peter15@gmail.com", role = "aut",
           comment = c(ORCID = "0009-0005-2524-4751")),
    person("Anna C.", "Reisetter", , "anna-reisetter@uiowa.edu", role = "aut",
           comment = c(ORCID = "0000-0001-8332-4585")),
    person("Yujing", "Lu", role = "aut"),
    person("Oscar A.", "Rysavy", , "oscar-rysavy@uiowa.edu", role = "aut",
           comment = c(ORCID = "0000-0002-1019-5724")),
    person("Patrick J.", "Breheny", , "patrick-breheny@uiowa.edu", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-0650-1119"))
  )
Description: Fits penalized linear mixed models that correct for
    unobserved confounding factors. 'plmmr' infers and corrects for the
    presence of unobserved confounding effects such as population
    stratification and environmental heterogeneity. It then fits a linear
    model via penalized maximum likelihood. Originally designed for the
    multivariate analysis of single nucleotide polymorphisms (SNPs)
    measured in a genome-wide association study (GWAS), 'plmmr' eliminates
    the need for subpopulation-specific analyses and post-analysis p-value
    adjustments. Functions for the appropriate processing of 'PLINK'
    files are also supplied. For examples, see the package homepage
    <https://pbreheny.github.io/plmmr/>.
License: GPL-3
URL: https://pbreheny.github.io/plmmr/,
        https://github.com/pbreheny/plmmr/
BugReports: https://github.com/pbreheny/plmmr/issues/
Depends: bigalgebra, bigmemory, R (>= 4.4.0)
Imports: biglasso (>= 1.6.0), data.table, glmnet, Matrix, ncvreg,
        parallel, utils
Suggests: bigsnpr, bigstatsr, graphics, grDevices, knitr, MASS,
        rmarkdown, R.utils, tinytest, withr
LinkingTo: BH, bigmemory, Rcpp, RcppArmadillo (>= 0.8.600)
LazyData: true
VignetteBuilder: knitr
Encoding: UTF-8
Config/roxygen2/version: 8.0.0
NeedsCompilation: yes
Packaged: 2026-05-19 13:27:29 UTC; pbreheny
Author: Tabitha K. Peter [aut] (ORCID: <https://orcid.org/0009-0005-2524-4751>),
  Anna C. Reisetter [aut] (ORCID:
    <https://orcid.org/0000-0001-8332-4585>),
  Yujing Lu [aut],
  Oscar A. Rysavy [aut] (ORCID: <https://orcid.org/0000-0002-1019-5724>),
  Patrick J. Breheny [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-0650-1119>)
Maintainer: Patrick J. Breheny <patrick-breheny@uiowa.edu>
Repository: CRAN
Date/Publication: 2026-06-11 07:20:02 UTC
Built: R 4.5.2; x86_64-apple-darwin20; 2026-06-11 08:56:14 UTC; unix
Archs: plmmr.so.dSYM
