# Generated by roxygen2: do not edit by hand

S3method(coef,cv_plmm)
S3method(coef,plmm)
S3method(plot,cv_plmm)
S3method(plot,plmm)
S3method(predict,cv_plmm)
S3method(predict,plmm)
S3method(print,summary.cv_plmm)
S3method(print,summary.plmm)
S3method(summary,cv_plmm)
S3method(summary,plmm)
export(create_design)
export(cv_plmm)
export(find_example_data)
export(plmm)
export(plmm_loss)
export(process_delim)
export(process_plink)
export(relatedness_mat)
export(unzip_example_data)
import(stats)
importFrom(bigalgebra,Arith)
importFrom(bigmemory,attach.big.matrix)
importFrom(bigmemory,big.matrix)
importFrom(bigmemory,sub.big.matrix)
importFrom(data.table,merge.data.table)
importFrom(glmnet,glmnet)
importFrom(utils,packageVersion)
importFrom(utils,setTxtProgressBar)
importFrom(utils,txtProgressBar)
useDynLib(plmmr, .registration=TRUE)
